<?php
namespace Modules\Cadastros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;
use Modules\Cadastros\Services\gql00200GrupoDeOcorrenciasService;

class gql00200GrupoDeOcorrenciasController
{
    protected $connection;
    
    public function __construct (gql00200GrupoDeOcorrenciasService $service, $connection)
    {
        $this->service       = $service;
        $this->connection    = $connection;
    }
    
    public function insertGrupoOcorrencia(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            
            self::verifyGrupoOcorrencia($row, $response);
            
            $descricao = $this->service->getDescricao($row);
            if ($descricao) {
            	throw new \Exception("DESC_CADASTRADA");	
            }
            
            $this->service->insertGrupoOcorrencia($row);
            
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function updateGrupoOcorrencia(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            
            $descricao = $this->service->getDescricao($row);
            if ($descricao) {
            	throw new \Exception("DESC_CADASTRADA");	
            }
            
            $this->service->updateGrupoOcorrencia($row);
            
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function deleteGrupoOcorrencia(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            
            $this->service->deleteGrupoOcorrencia($row);
            
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function verifyGrupoOcorrencia($row, $response)
    {
        if ($this->service->getGrupoOcorrencia($row)[0]['RETORNO'] > 0) {
            throw new \Exception("CODIGO_CADASTRADO");
        }
    }
}